part of 'additional_item_bloc.dart';

abstract class AdditionalItemState extends Equatable {
  const AdditionalItemState();

  @override
  List<Object> get props => [];
}

class AdditionalItemsLoading extends AdditionalItemState {}

class AdditionalItemsLoaded extends AdditionalItemState {
  const AdditionalItemsLoaded(this.items);
  final List<AdditionalItems> items;

  @override
  List<Object> get props => [items];
}

class ShowAddItemsScreen extends AdditionalItemState {}

class AdditionalItemsErrorState extends AdditionalItemState {
  const AdditionalItemsErrorState(this.error);
  final String error;

  @override
  List<Object> get props => [error];
}

class AdditionalItemsDeletedState extends AdditionalItemState {
  final bool success;
  const AdditionalItemsDeletedState({required this.success});
  @override
  List<Object> get props => [success];
}
